pub struct PoolUpdateProperties {
pub provisioning_state: Option<ProvisioningState>,
pub maximum_concurrency: Option<i32>,
pub organization_profile: Option<OrganizationProfileUnion>,
pub agent_profile: Option<AgentProfileUnion>,
pub fabric_profile: Option<FabricProfileUnion>,
pub dev_center_project_resource_id: Option<String>,
}Expand description
The updatable properties of the Pool.
Fields
provisioning_state: Option<ProvisioningState>The status of the current operation.
maximum_concurrency: Option<i32>Defines how many resources can there be created at any given time.
organization_profile: Option<OrganizationProfileUnion>Defines the organization in which the pool will be used.
agent_profile: Option<AgentProfileUnion>The agent profile of the machines in the pool.
fabric_profile: Option<FabricProfileUnion>Defines the type of fabric the agent will run on.
dev_center_project_resource_id: Option<String>The resource id of the DevCenter Project the pool belongs to.
Implementations